@@ -73,12 +73,8 @@ void sp_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
     a = 6378.137;              /* WGS-84 equatorial radius in km */
     f = 1.0/298.257223563;     /* WGS-84 ellipsoid flattening factor */
     
-    if (fabs(lat1[0] - lat2[0]) < DOUBLE_EPS) {
-        if (fabs(lon1[0] - lon2[0]) < DOUBLE_EPS) {
-            dist[0] = 0.0;
-            return;
-/* Wouter Buytaert bug caught 100211 */
-        } else if (fabs((fabs(lon1[0]) + fabs(lon2[0])) - 360.0) < DOUBLE_EPS) {
+    if (fabs(lat1[0] - lat2[0]) < DBL_EPSILON) {
+        if (fabs(fmod(lon1[0] - lon2[0], 360.0)) < DBL_EPSILON) {
             dist[0] = 0.0;
             return;
         }
@@ -111,7 +107,7 @@ void sp_gcdist(double *lon1, double *lon2, double *lat1, double *lat2,
 
     D = 2*w*a;
     H1 = ( 3*R - 1 )/( 2*C );
-    H2 = ( 3*R + 2 )/( 2*S );
+    H2 = ( 3*R + 1 )/( 2*S );
 
     dist[0] = D*( 1 + f*H1*sinF2*cosG2 - f*H2*cosF2*sinG2 ); 
 
